import _plotly_utils.basevalidators


class NotchedValidator(_plotly_utils.basevalidators.BooleanValidator):

    def __init__(self, plotly_name='notched', parent_name='box', **kwargs):
        super(NotchedValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type='calc',
            role='style',
            **kwargs
        )
